@@ -1,17 +1,14 @@
 
-BEGIN {
-
 package Tie::STDERR;
 
 use strict;
 
-my $stderr;
+my $stderr;			### here we store the STDERR output
 
 sub TIEHANDLE
 	{
 	my $class = shift;
-	my $self = \$stderr;
-	bless $self, $class;
+	bless {}, $class;
 	}
 sub PRINT
 	{
@@ -20,18 +17,11 @@ sub PRINT
 	$stderr .= join	'', @_;
 	}
 
-untie *STDERR;
-tie *STDERR, __PACKAGE__;
-
-$SIG{__WARN__} = sub { print STDERR @_; };
-
-$SIG{__DIE__} = sub { print STDERR @_; };
-
-my $user = 'root';				### change this to 'root'
-my $subject = 'STDERR output detected';		### change this to your Subject
+my $default_user = 'root';			### change this to 'root'
+my $default_subject = 'STDERR output detected';	### change this to your Subject
 my $default_mail = '| /usr/lib/sendmail -t';	### default command
 
-my $command;
+my ($user, $subject, $command);
 
 END {
 	if (defined $stderr)
@@ -57,7 +47,29 @@ sub import
 	{
 	### print "Import @_ called\n";
 	my $class = shift;
+
+	if (@_ and not defined $_[0])	### explicit undef
+		{
+		$^W = 0;
+		untie *STDERR if ref tied *STDERR eq 'Tie::STDERR';
+		return;
+		}
+
+	return if -t STDERR or -t STDOUT;
+
+	unless (ref tied *STDERR eq 'Tie::STDERR')
+		{
+		tie *STDERR, __PACKAGE__;
+
+		$SIG{__WARN__} = sub { print STDERR @_; };
+
+		$SIG{__DIE__} = sub { print STDERR @_; };
+		}
+
+	($user, $subject, $command) = ($default_user, $default_subject, undef);
+
 	return unless @_;
+
 	my $arg = shift;
 	if ($arg =~ /^\s*[|>]/)
 		{ $command = $arg; }
@@ -70,9 +82,10 @@ sub import
 			{ $arg =~ s/\n$//; $subject = $arg; }
 		}
 	}
-}
 
-$VERSION = '0.10';
+use vars qw( $VERSION );
+
+$VERSION = '0.122';
 
 1;
 
@@ -101,20 +114,21 @@ Send all output that would otherwise go to STDERR either by email to
 root or whoever is responsible, or to a file or a process. This way
 you can change the destination of your error messages from inside of
 your script. The mail will be sent or the command run only if there
-actually is some output detected -- something like cron does.
+actually is some output detected -- something like cron would do.
 
-The behavior of the module is driven using the arguments to use, as
+The behaviour of the module is directed via the arguments to use, as
 shown above. You can optionally give the name of the recipient and the
 subject of the email. Argument that starts with | will send the output 
 to a process. If it starts with > or >>, it will be written (appended)
-to a file.
+to a file. If the argument is explicit undef, if will untie previous
+tieness.
 
 My main goal was to provide a tool that could be used easily,
-especially for CGI scripts. My assumption is that the CGI scripts
-should run without anything being sent to STDERR (and error_log, where
-it mixes up with other messages, even if you use CGI::Carp). I've
-found it usefull to get delivered any problem including the relevant
-information (%ENV) by email.
+especially (but not only) for CGI scripts. My assumption is that the
+CGI scripts should run without anything being sent to STDERR (and
+error_log, where it mixes up with other messages, even if you use
+CGI::Carp). I've found it usefull to get delivered any relevant
+information (%ENV) via email.
 
 =head1 BUGS
 
@@ -123,7 +137,7 @@ the reason, only the fact that there was an error.
 
 =head1 VERSION
 
-0.10
+0.122
 
 =head1 AUTHOR
 
